@@ -12,6 +12,13 @@ from rdkit.Chem import AllChem
 
 class MolSmiles:
 
+    @classmethod
+    def remove_map_num(cls, smiles: str) -> str:
+        rdmol = AllChem.MolFromSmarts(smiles)
+        for atom in rdmol.GetAtoms():
+            atom.SetAtomMapNum(0)
+        return AllChem.MolToSmiles(rdmol)
+
     @classmethod
     def get_smiles_without_map_num(cls, rdmol: Mol) -> str:
         _rdmol = copy.deepcopy(rdmol)
@@ -21,5 +28,4 @@ class MolSmiles:
 
 
 if __name__ == "__main__":
-    rxn = AllChem.MolFromSmiles("[F:1][C:2]1[CH:7]=[CH:6][C:5](Br)=[CH:4][N:3]=1")
-    print(MolSmiles.get_smiles_without_map_num(rxn))
+    print(MolSmiles.remove_map_num('[c:1][c:2]=N'))
